@@ -11,8 +11,7 @@ from trytond.wizard import Wizard, StateView, StateTransition, Button
 __all__ = ['Journal', 'Payment', 'Succeed', 'SucceedStart']
 
 
-class Journal:
-    __metaclass__ = PoolMeta
+class Journal(metaclass=PoolMeta):
     __name__ = 'account.payment.journal'
     clearing_account = fields.Many2One('account.account', 'Clearing Account',
         domain=[('party_required', '=', False)],
@@ -25,10 +24,34 @@ class Journal:
             'required': Bool(Eval('clearing_account')),
             },
         depends=['clearing_account'])
+    clearing_posting_delay = fields.TimeDelta(
+        "Clearing Posting Delay",
+        help="Post automatically the clearing moves after the delay.\n"
+        "Leave empty for no posting.")
+
+    @classmethod
+    def cron_post_clearing_moves(cls, date=None):
+        pool = Pool()
+        Date = pool.get('ir.date')
+        Move = pool.get('account.move')
+        if date is None:
+            date = Date.today()
+        moves = []
+        journals = cls.search([
+                ('clearing_posting_delay', '!=', None),
+                ])
+        for journal in journals:
+            move_date = date - journal.clearing_posting_delay
+            moves.extend(Move.search([
+                        ('date', '<=', move_date),
+                        ('origin.journal.id', '=', journal.id,
+                            'account.payment'),
+                        ('state', '=', 'draft'),
+                        ]))
+        Move.post(moves)
 
 
-class Payment:
-    __metaclass__ = PoolMeta
+class Payment(metaclass=PoolMeta):
     __name__ = 'account.payment'
     account = fields.Many2One(
         'account.account', "Account", ondelete='RESTRICT',
@@ -212,7 +235,7 @@ class Payment:
         if to_delete:
             Move.delete(to_delete)
         for party in to_reconcile:
-            for lines in to_reconcile[party].itervalues():
+            for lines in to_reconcile[party].values():
                 Line.reconcile(lines)
 
 
